# CSET (Convective and turbulence scale Evaluation and verification Toolkit)

CSET is a toolkit for evaluation, verification and investigation of convective-
and turbulence-scale numerical models for weather and climate applications,
cutting across time and space scales.

It aligns parametrisation development, diagnostic development and evaluation
research, feeding back into Regional Atmosphere and Land (RAL) model development
across the Met Office and UM partnership.

Apart from verification capabilities it provides a centralised source of tools
to aid process-oriented evaluation for UM and LFRic models, supporting both
deterministic and ensembles.

For model developers CSET offers well documented and peer reviewed evaluation
tools and flexible evaluation code that can adapt to users needs.

For diagnostic developers it provides a legacy for diagnostics and observations.
It is build on a modern software stack using python 3 and METplus. Clear
documentation, working practices, automatic testing, and open access promote
contributions.

Please read [the documentation](https://metoffice.github.io/CSET) to learn more
about CSET, and how to use it.

If you want to ask or share with the CSET community, please use the relevant
category of the [Simulation Systems Discussions
Forum](https://github.com/MetOffice/simulation-systems/discussions/categories/cset-toolkit).

## Contributing

Contributions are readily welcomed! To get started with developing CSET visit
the [Contributing](https://metoffice.github.io/CSET/contributing/) section of
the documentation.

In addition to reading the working practices, the key
recommendation is early communication. Open an [issue on
Github](https://github.com/MetOffice/CSET/issues) with your proposed change or
addition in the design phase, and then others can provide guidance early.

## Licence

© Crown copyright, Met Office (2022-2024) and CSET contributors.

Licensed under the [Apache License, Version 2.0](LICENCE) (the "License"); you
may not use this file except in compliance with the License. You may obtain a
copy of the License at

<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

GitHub Copilot was used in the development of this software.
